mod image;

use image::{Color, Image};

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let c1 = Color {
        red: 255,
        green: 0,
        blue: 0,
    };
    let c2 = Color {
        red: 0,
        green: 0,
        blue: 155,
    };
    println!("c1: {:?}", c1);
    println!("c2: {:?}", c2);

    let uni_img = Image::new_unicolor("red".to_owned(), 300, 200, c1);
    let (w, h) = uni_img.size();
    println!("Image {:?} with size {}×{}", uni_img.name(), w, h);
    uni_img.save(&format!("results/{}.ppm", uni_img.name()))?;

    let rnd_img = Image::new_random("random".to_owned(), 300, 200);
    let (w, h) = rnd_img.size();
    println!("Image {:?} with size {}×{}", rnd_img.name(), w, h);
    rnd_img.save(&format!("results/{}.ppm", rnd_img.name()))?;

    for path in [
        "data/arton80.ppm",
        "data/informatique.ppm",
        "data/planete.ppm",
    ] {
        let mut img = Image::new_from_rgb(path)?;
        let (w, h) = img.size();
        println!("Image {:?} with size {}×{}", img.name(), w, h);
        img.grey();
        img.save(&format!("results/{}.ppm", img.name()))?;
    }

    for path in [
        "data/nao_V4L_0.yuyv",
        "data/nao_V4L_1.yuyv",
        "data/nao_capture.yuyv",
    ] {
        let mut img = Image::new_from_yuv(path)?;
        let (w, h) = img.size();
        println!("Image {:?} with size {}×{}", img.name(), w, h);
        img.save(&format!("results/{}.ppm", img.name()))?;
        img.grey();
        img.save(&format!("results/{}.ppm", img.name()))?;
    }

    Ok(())
}
